@@ -1,3 +1,4 @@
+#utils::globalVariables(c("y"))
 setClass("MTP",representation(statistic="numeric",
                               estimate="numeric",
                               sampsize="numeric",
@@ -575,7 +576,11 @@ print.MTP<-function(x,...){
   n<-length(snames)
   out<-matrix(nrow=n,ncol=4)
   dimnames(out)<-list(snames,c("Class","Mode","Length","Dimension"))
-  for(s in snames) out[s,]<-c(class(slot(x,s)),mode(slot(x,s)),length(slot(x,s)),paste(dim(slot(x,s)),collapse=","))
+  for(s in snames){
+      out[s,]<-c(class(slot(x,s))[1],mode(slot(x,s)),length(slot(x,s)),
+                 paste(dim(slot(x,s)),collapse=","))
+      #added [1] to fix the bug
+  }
   out<-data.frame(out)
   print(out)
   invisible(x)
